@@ -20,14 +20,14 @@ use Icinga\Module\Icingadb\Widget\Detail\ObjectsDetail;
 use Icinga\Module\Icingadb\Widget\ItemList\ServiceList;
 use Icinga\Module\Icingadb\Widget\ItemTable\ServiceItemTable;
 use Icinga\Module\Icingadb\Widget\ServiceStatusBar;
-use Icinga\Module\Icingadb\Widget\ShowMore;
 use Icinga\Module\Icingadb\Web\Control\ViewModeSwitcher;
+use Icinga\Module\Icingadb\Widget\ShowMore;
+use Icinga\Util\Environment;
 use ipl\Html\HtmlString;
 use ipl\Orm\Query;
 use ipl\Stdlib\Filter;
 use ipl\Web\Control\LimitControl;
 use ipl\Web\Control\SortControl;
-use ipl\Web\Filter\QueryString;
 use ipl\Web\Url;
 
 class ServicesController extends Controller
@@ -63,11 +63,11 @@ class ServicesController extends Controller
         $sortControl = $this->createSortControl(
             $services,
             [
-                'service.display_name'                 => t('Name'),
-                'service.state.severity desc'          => t('Severity'),
-                'service.state.soft_state'             => t('Current State'),
-                'service.state.last_state_change desc' => t('Last State Change'),
-                'host.display_name'                    => t('Host')
+                'service.display_name'                                             => t('Name'),
+                'service.state.severity desc,service.state.last_state_change desc' => t('Severity'),
+                'service.state.soft_state'                                         => t('Current State'),
+                'service.state.last_state_change desc'                             => t('Last State Change'),
+                'host.display_name'                                                => t('Host')
             ]
         );
         $viewModeSwitcher = $this->createViewModeSwitcher($paginationControl, $limitControl);
@@ -131,7 +131,9 @@ class ServicesController extends Controller
                     ))
             );
         } else {
-            $this->addFooter((new ServiceStatusBar($summary->first()))->setBaseFilter($filter));
+            /** @var ServicestateSummary $servicesSummary */
+            $servicesSummary = $summary->first();
+            $this->addFooter((new ServiceStatusBar($servicesSummary))->setBaseFilter($filter));
         }
 
         if (! $searchBar->hasBeenSubmitted() && $searchBar->hasBeenSent()) {
@@ -182,10 +184,11 @@ class ServicesController extends Controller
         $this->addControl(
             (new ServiceList($results))
                 ->setViewMode('minimal')
+                ->setDetailActionsDisabled()
         );
         $this->addControl(new ShowMore(
             $results,
-            Links::services()->setQueryString(QueryString::render($this->getFilter())),
+            Links::services()->setFilter($this->getFilter()),
             sprintf(t('Show all %d services'), $services->count())
         ));
         $this->addControl(
@@ -222,6 +225,8 @@ class ServicesController extends Controller
 
     public function gridAction()
     {
+        Environment::raiseExecutionTime();
+
         $db = $this->getDb();
         $this->addTitleTab(t('Service Grid'));
 
@@ -234,11 +239,14 @@ class ServicesController extends Controller
 
         $this->handleSearchRequest($query);
 
+        // Create problem toggle before shifting params. Otherwise, the toggle
+        // will redirect to the grid without the shifted params.
+        $problemToggle = $this->createProblemToggle();
+
         $this->params->shift('page'); // Handled by PivotTable internally
         $this->params->shift('limit'); // Handled by PivotTable internally
         $flipped = $this->params->shift('flipped', false);
 
-        $problemToggle = $this->createProblemToggle();
         $sortControl = $this->createSortControl($query, [
             'service.display_name' => t('Service Name'),
             'host.display_name' => t('Host Name'),
@@ -299,7 +307,6 @@ class ServicesController extends Controller
                 ->setYAxisHeader('host_display_name');
         }
 
-
         $this->view->horizontalPaginator = $pivot->paginateXAxis();
         $this->view->verticalPaginator = $pivot->paginateYAxis();
         list($pivotData, $pivotHeader) = $pivot->toArray();
@@ -307,7 +314,7 @@ class ServicesController extends Controller
         $this->view->pivotHeader = $pivotHeader;
 
         /** Preserve filter and params in view links (the `BaseFilter` implementation for view scripts -.-) */
-        $this->view->baseUrl = $this->getRequest()->getUrl()
+        $this->view->baseUrl = Url::fromRequest()
             ->onlyWith([
                 LimitControl::DEFAULT_LIMIT_PARAM,
                 $sortControl->getSortParam(),
@@ -316,15 +323,7 @@ class ServicesController extends Controller
                 'problems'
             ]);
         $preservedParams = $this->view->baseUrl->getParams();
-        $this->view->baseUrl->setQueryString(QueryString::render($filter));
-        foreach ($preservedParams->toArray(false) as $name => $value) {
-            if (is_int($name)) {
-                $name = $value;
-                $value = true;
-            }
-
-            $this->view->baseUrl->getParams()->addEncoded($name, $value);
-        }
+        $this->view->baseUrl->setFilter($filter);
 
         $searchBar->setEditorUrl(Url::fromPath(
             "icingadb/services/grid-search-editor"
@@ -398,7 +397,7 @@ class ServicesController extends Controller
 
     protected function getCommandTargetsUrl(): Url
     {
-        return Links::servicesDetails()->setQueryString(QueryString::render($this->getFilter()));
+        return Links::servicesDetails()->setFilter($this->getFilter());
     }
 
     protected function getFeatureStatus()
@@ -409,12 +408,14 @@ class ServicesController extends Controller
         return new FeatureStatus('service', $summary->first());
     }
 
-    protected function prepareSearchFilter(Query $query, string $search, Filter\Any $filter)
+    protected function prepareSearchFilter(Query $query, string $search, Filter\Any $filter, array $additionalColumns)
     {
         if ($this->params->shift('_hostFilterOnly', false)) {
-            $filter->add(Filter::like('host.name_ci', "*$search*"));
+            foreach (['host.name_ci', 'host.display_name', 'host.address', 'host.address6'] as $column) {
+                $filter->add(Filter::like($column, "*$search*"));
+            }
         } else {
-            parent::prepareSearchFilter($query, $search, $filter);
+            parent::prepareSearchFilter($query, $search, $filter, $additionalColumns);
         }
     }
 
