@@ -6,10 +6,10 @@ namespace Icinga\Module\Icingadb\Model;
 
 use DateTime;
 use Icinga\Module\Icingadb\Model\Behavior\BoolCast;
+use Icinga\Module\Icingadb\Common\Model;
 use ipl\Orm\Behavior\Binary;
 use ipl\Orm\Behavior\MillisecondTimestamp;
 use ipl\Orm\Behaviors;
-use ipl\Orm\Model;
 use ipl\Orm\Relations;
 
 /**
