@@ -8,9 +8,27 @@ use Icinga\Module\Icingadb\Model\Behavior\Bitmask;
 use Icinga\Module\Icingadb\Model\Behavior\ReRoute;
 use ipl\Orm\Behavior\Binary;
 use ipl\Orm\Behaviors;
-use ipl\Orm\Model;
+use Icinga\Module\Icingadb\Common\Model;
 use ipl\Orm\Relations;
 
+/**
+ * @property string $id
+ * @property string $environment_id
+ * @property string $name_checksum
+ * @property string $properties_checksum
+ * @property string $name
+ * @property string $name_ci
+ * @property string $host_id
+ * @property ?string $service_id
+ * @property string $notificationcommand_id
+ * @property ?int $times_begin
+ * @property ?int $times_end
+ * @property int $notification_interval
+ * @property ?string $timeperiod_id
+ * @property string[] $states
+ * @property string[] $types
+ * @property ?string $zone_id
+ */
 class Notification extends Model
 {
     public function getTableName()
